@@ -37,27 +37,13 @@ class Dependencies:
         bdep = self.bdep = bdep or {}
         self.is_debug_package = dbgpkg = package.endswith('-dbg')
 
-        # TODO: move it to PyPy and CPython{2,3} classes
         self.ipkg_vtpl = 'python%s-dbg' if dbgpkg else 'python%s'
-        if impl == 'cpython3':
-            self.ipkg_tpl = 'python3-dbg' if dbgpkg else 'python3'
-        elif impl == 'cpython2':
-            self.ipkg_tpl = 'python2-dbg' if dbgpkg else 'python2'
-        elif impl == 'pypy':
-            self.ipkg_tpl = 'pypy-dbg' if dbgpkg else 'pypy'
-            self.ipkg_vtpl = 'pypy%s-dbg' if dbgpkg else 'pypy%s'
-        if impl == 'pypy':
-            self.ipkg_tpl_ma = self.ipkg_tpl
-            self.ipkg_vtpl_ma = self.ipkg_vtpl
-        else:
-            self.ipkg_tpl_ma = self.ipkg_tpl + ':any'
-            self.ipkg_vtpl_ma = self.ipkg_vtpl + ':any'
+        self.ipkg_tpl = 'python3-dbg' if dbgpkg else 'python3'
+        self.ipkg_tpl_ma = self.ipkg_tpl + ':any'
+        self.ipkg_vtpl_ma = self.ipkg_vtpl + ':any'
 
         self.python_dev_in_bd = 'python-dev' in bdep or\
                                 'python-all-dev' in bdep or\
-                                'python2-dev' in bdep or\
-                                'python2-all-dev' in bdep or\
-                                'python2.7-dev' in bdep or\
                                 'python3-dev' in bdep or\
                                 'python3-all-dev' in bdep
 
@@ -139,23 +125,6 @@ class Dependencies:
             if maxv:
                 self.depend("%s (<< %s)" % (tpl_tmp, maxv))
 
-        if self.impl == 'cpython2' and stats['public_vers']:
-            # additional Depends to block python package transitions
-            sorted_vers = sorted(stats['public_vers'])
-            minv = sorted_vers[0]
-            maxv = sorted_vers[-1]
-            if minv <= default(self.impl):
-                self.depend("%s (>= %s~)" % (tpl_ma, minv))
-            if maxv >= default(self.impl):
-                self.depend("%s (<< %s)" % (tpl_ma, maxv + 1))
-
-        if self.impl == 'pypy' and stats.get('ext_soabi'):
-            # TODO: make sure alternative is used only for the same extension names
-            # ie. for foo.ABI1.so, foo.ABI2.so, bar.ABI3,so, bar.ABI4.so generate:
-            # pypy-abi-ABI1 | pypy-abi-ABI2, pypy-abi-ABI3 | pypy-abi-ABI4
-            self.depend('|'.join(soabi.replace('-', '-abi-')
-                                 for soabi in sorted(stats['ext_soabi'])))
-
         if stats['ext_vers']:
             # TODO: what about extensions with stable ABI?
             sorted_vers = sorted(stats['ext_vers'])
@@ -172,7 +141,7 @@ class Dependencies:
             self.depend(MINPYCDEP[self.impl])
 
         for ipreter in stats['shebangs']:
-            self.depend("%s%s" % (ipreter, '' if self.impl == 'pypy' else ':any'))
+            self.depend("%s:any" % ipreter)
 
         supported_versions = supported(self.impl)
         default_version = default(self.impl)
@@ -224,8 +193,8 @@ class Dependencies:
                         if vrange.maxver:  # maximum version specified
                             self.depend("%s (<< %s)" % (tpl_ma, vrange.maxver + 1))
 
-                for pattern in options.regexpr or []:
-                    args += " -X '%s'" % pattern.replace("'", r"'\''")
+                for regex in options.regexpr or []:
+                    args += " -X '%s'" % regex.pattern.replace("'", r"'\''")
                 self.rtscript((private_dir, args))
 
         section_options = {
@@ -240,6 +209,7 @@ class Dependencies:
                 # TODO: should options.recommends and options.suggests be
                 # removed from requires.txt?
                 deps = parse_pydep(self.impl, fn, bdep=self.bdep, **section_options)
+                # pylint: disable=expression-not-assigned
                 [self.depend(i) for i in deps['depends']]
                 [self.recommend(i) for i in deps['recommends']]
                 [self.suggest(i) for i in deps['suggests']]
@@ -252,6 +222,7 @@ class Dependencies:
             for fpath in stats['dist-info']:
                 deps = parse_requires_dist(self.impl, fpath, bdep=self.bdep,
                                            **section_options)
+                # pylint: disable=expression-not-assigned
                 [self.depend(i) for i in deps['depends']]
                 [self.recommend(i) for i in deps['recommends']]
                 [self.suggest(i) for i in deps['suggests']]
@@ -271,9 +242,10 @@ class Dependencies:
             if not exists(fpath):
                 fpath = fn
                 if not exists(fpath):
-                    log.warn('cannot find requirements file: %s', fn)
+                    log.warning('cannot find requirements file: %s', fn)
                     continue
             deps = parse_pydep(self.impl, fpath, bdep=self.bdep, **section_options)
+            # pylint: disable=expression-not-assigned
             [self.depend(i) for i in deps['depends']]
             [self.recommend(i) for i in deps['recommends']]
             [self.suggest(i) for i in deps['suggests']]
