@@ -41,37 +41,24 @@ else:
         'http://ftp.debian.org/debian/dists/unstable/main/Contents-amd64.gz',
     ]
 
-IGNORED_PKGS = {'python-setuptools', 'python3-setuptools', 'pypy-setuptools'}
+IGNORED_PKGS = {'python3-setuptools'}
 OVERRIDES = {
-    'cpython2': {
-        'python': 'python',
-        'setuptools': 'python-pkg-resources',
-        'wsgiref': 'python (>= 2.5) | python-wsgiref',
-        'argparse': 'python (>= 2.7) | python-argparse',
-        # not recognized due to .pth file (egg-info is in PIL/ and not in *-packages/)
-        'pil': 'python-pil',
-        'Pillow': 'python-pil'},
     'cpython3': {
-        'pil': 'python3-pil',
+        'Cython': 'cython3',
         'Pillow': 'python3-pil',
+        'PySide6': None,
+        'argparse': 'python3 (>= 3.2)',
+        'pil': 'python3-pil',
         'pylint': 'pylint',
         'setuptools': 'python3-pkg-resources',
-        'argparse': 'python3 (>= 3.2)'},
-    'pypy': {}
+    },
 }
 
 public_egg = re.compile(r'''
     /usr/
     (
-        (?P<cpython2>
-            (lib/python2\.[0-9]/((site)|(dist))-packages)|
-            (share/python-support/[^/]+)
-        )|
         (?P<cpython3>
             (lib/python3/dist-packages)
-        )|
-        (?P<pypy>
-            (lib/pypy/dist-packages)
         )
     )
     /[^/]*\.(dist|egg)-info
@@ -108,13 +95,7 @@ result = {
     'cpython3': {}
 }
 
-# Contents file doesn't contain comment these days
-is_header = not data.startswith('bin')
 for line in data.splitlines():
-    if is_header:
-        if line.startswith('FILE'):
-            is_header = False
-        continue
     try:
         path, desc = line.rsplit(maxsplit=1)
     except ValueError:
@@ -137,6 +118,9 @@ for line in data.splitlines():
                 sensible_pname(impl, egg_name) == pkg_name:
             continue
 
+        if impl not in result:
+            continue
+
         processed = result[impl]
         if egg_name not in processed:
             processed[egg_name] = pkg_name
@@ -146,7 +130,8 @@ for impl, details in result.items():
         overrides = OVERRIDES[impl]
         lines = []
         for egg, value in overrides.items():
-            lines.append('{} {}\n'.format(egg, value))
+            if value:
+                lines.append('{} {}\n'.format(egg, value))
         lines.extend(
             '{} {}\n'.format(egg, pkg) for egg, pkg in details.items() if egg not in overrides
         )
